/*******************************************************************
* FILENAME: inst.h
*
* DESCRIPTION:
*	Interface and prototypes for functions in instvc library
*
* REFERENCES:
*
********************************************************************/

#ifndef INCLUDED_INST_H
#define	INCLUDED_INST_H
#endif
//#ifndef UNICODE
//#define	UNICODE
//#endif

// exported "C" functions from instvc.dll
// note:  must be "C" and not "C++" -- so they won't be name mangled
// and can be called from within the InstallShield installer....

//	admin accounts
extern "C" int __declspec(dllexport) AddTCBPrivilege();

//	current process
extern "C" int __declspec(dllexport) VerifyTCBPrivilege();

// registers a file (*.exe, *.dll, or *.ocx)
// RegisterFile( filename ) -- fully qualified path to file
extern "C" int __declspec(dllexport) RegisterFile(const char * );

// add a local administrator account using the LSA api
// AddUserAccount( domain, userID, userPass )
extern "C" int __declspec(dllexport) AddUserAccount(LPSTR , const char *, const char * );

//	returns the name of the current machine
//	GetMachineName( machineName )
extern "C" int __declspec(dllexport) GetMachineName(char *);

//	returns 1 if this machine is member of a workgroup, 0 otherwise, -1 failure
extern "C" int __declspec(dllexport) IsWorkgroup();

//	returns 1 if this machine is a PDC, 0 otherwise, -1 failure
extern "C" int __declspec(dllexport) IsPrimaryDomainController();

//	returns 1 if this machine is a BDC, 0 otherwise, -1 failure
extern "C" int __declspec(dllexport) IsBackupDomainController();

//	returns the name of the current domain
//	GetDomainName( "\\MXB", domainName )
extern "C" int __declspec(dllexport) GetDomainName(const char *, char *);

//	return the name of the PDC, -1 if there is none, 
//	GetPDCMachineName( "\\MXB", "SBKDOMAIN", pdcMachineName )
//	GetPDCMachineName( 0, 0, pdcMachineName ) for this machine
extern "C" int __declspec(dllexport) GetPDCMachineName(const char *, const char *, char *);

//	returns a ';' delimited list of trusted domains in machineName (can be null = local)
//	EnumTrustedDomains("test-pdc", domainList) -- domainList => "domainA;domainB"
extern "C" int __declspec(dllexport) EnumTrustedDomains(const char *machineName, char *domains);

// returns a ';' delimited list of locally defined administrator accounts
// EnumAdminAccount( machineName, accountsList ) -- accountsList => "Administrator;Joe;Steve"
extern "C" int __declspec(dllexport) EnumAdminAccounts(const char *, char * );

// sets a service to run under a specified user context (run as)
// SetServiceRunAs( serviceName, accountName, accountPassword )
// note: accountName == COMPUTERNAME\\ACCOUNTID
extern "C" long __declspec(dllexport) SetServiceRunAs(const char *, const char *, const char * );

// configures passed account to have policy to enable log on as service
// SetPolicy( accountName )
// note: accountName == COMPUTERNAME\\ACCOUNTID
extern "C" int __declspec(dllexport) SetPolicy( const char * );

// launches a process in a minimized state a waits for completion
// LaunchMinimized( fileName, parms, path )
// note: fileName is fully qualified including extension
extern "C" int __declspec(dllexport) LaunchMinimized( const char *, char *, const char * );

// stops specified service
// StopService( serviceName )
extern "C" long __declspec(dllexport) StopService(const char * );

// removes specified service
// RemoveService( serviceName )
// the specified service should have been stopped with a prior call to StopService()
extern "C" long __declspec(dllexport) RemoveService(const char * );

// flush a registry key write to disk
// FlushRegistryKey( key );
// forces any pending writes to the hive to be done
extern "C" int __declspec(dllexport) FlushRegistryKey(const char * );

// lists default access permissions from the ACL (access control list) -- to the screen
extern "C" DWORD __declspec(dllexport) ListDefaultAccessACL( void );

// lists default launch permissions from the ACL (access control list) -- to the screen
extern "C" DWORD __declspec(dllexport) ListDefaultLaunchACL( void );

// lists the access permissions from the ACL for a specified AppID (GUID - COM object)
// ListAppIDAccessACL( guid ) -- where guid == "{CEAAD2E0-3868-11D2-B333-00AA00BD862B}" for example
extern "C" DWORD __declspec(dllexport) ListAppIDAccessACL( LPTSTR );

// lists the launch permissions from the ACL for a specified AppID (GUID - COM object)
// ListAppIDLaunchACL( guid ) -- where guid == "{CEAAD2E0-3868-11D2-B333-00AA00BD862B}" for example
extern "C" DWORD __declspec(dllexport) ListAppIDLaunchACL( LPTSTR  );

// changes the default access permissions for the specified account
// ChangeDefaultAccessACL( principal, setPrincipal, permit)
// principal = accountID
// setPrincipal - TRUE sets permissions to that specified in permit, FALSE removes principal from ACL
// permit - TRUE = default access, FALSE = no default access
extern "C" DWORD __declspec(dllexport) ChangeDefaultAccessACL( LPTSTR, BOOL, BOOL );

// changes the default launch permissions for the specified account
// ChangeDefaultLaunchACL( principal, setPrincipal, permit)
// principal = accountID
// setPrincipal - TRUE sets permissions to that specified in permit, FALSE removes principal from ACL
// permit - TRUE = default access, FALSE = no default access
extern "C" DWORD __declspec(dllexport) ChangeDefaultLaunchACL( LPTSTR, BOOL, BOOL );

// changes access control to specified AppID for specified principal
// ChangeAppIDAccessACL( guid, principal, setPrincipal, permit )
// guid = see ListAppIDAccessACL()
// principal = see above
// setPrincipal = see above
// permit = see above
extern "C" DWORD __declspec(dllexport) ChangeAppIDAccessACL( LPTSTR, LPTSTR, BOOL, BOOL );

// changes launch control to specified AppID for specified principal
// ChangeAppIDLaunchACL( guid, principal, setPrincipal, permit )
// guid = see ListAppIDAccessACL()
// principal = see above
// setPrincipal = see above
// permit = see above
extern "C" DWORD __declspec(dllexport) ChangeAppIDLaunchACL( LPTSTR, LPTSTR, BOOL, BOOL );

// get password from run as parameters for specified AppID (service)
// GetRunAsPassword( guid, password ) -- password is returned LPTSTR
extern "C" DWORD __declspec(dllexport) GetRunAsPassword( LPTSTR, LPTSTR );

// set the run as account for a specified AppID (service)
// SetRunAsPassword( guid, principal, password )
extern "C" DWORD __declspec(dllexport) SetRunAsPassword( LPTSTR, LPTSTR, LPTSTR );

// defines from Michael Nelsons DCOMPERM used in inst.cpp

typedef 
enum _DCP_ACLTYPE
    {	DCP_ACL_LAUNCH	= 1,
	DCP_ACL_ACCESS	= 2
    }	DCP_ACLTYPE;

typedef 
enum _DCP_AUTHN_LEVEL
    {	DCP_AUTHN_LEVEL_DEFAULT	= 0,
	DCP_AUTHN_LEVEL_NONE	= DCP_AUTHN_LEVEL_DEFAULT + 1,
	DCP_AUTHN_LEVEL_CONNECT	= DCP_AUTHN_LEVEL_NONE + 1,
	DCP_AUTHN_LEVEL_CALL	= DCP_AUTHN_LEVEL_CONNECT + 1,
	DCP_AUTHN_LEVEL_PKT	= DCP_AUTHN_LEVEL_CALL + 1,
	DCP_AUTHN_LEVEL_PKT_INTEGRITY	= DCP_AUTHN_LEVEL_PKT + 1,
	DCP_AUTHN_LEVEL_PKT_PRIVACY	= DCP_AUTHN_LEVEL_PKT_INTEGRITY + 1
    }	DCP_AUTHN_LEVEL;

typedef 
enum _DCOMPERM_RESULTS
    {	DCP_E_NO_ACCESS	= 0x8004a001,
	DCP_E_NO_ACL	= 0x8004a002,
	DCP_E_INVALID_OBJECT	= 0x8004a003,
	DCP_E_INVALID_TYPE	= 0x8004a004,
	DCP_E_MUST_BE_ADMIN	= 0x8004a005,
	DCP_E_NO_MORE_ENTRIES	= 0x8004a006,
	DCP_E_INVALID_VERSION	= 0x8004a007,
	DCP_E_OBJ_IS_A_SERVICE	= 0x8004a008,
	DCP_E_UNSUPPORTED	= 0x8004a009,
	DCP_E_NO_VALUE	= 0x8004a00a,
	DCP_E_UNKNOWN_USER	= 0x8004a00b,
	DCP_E_NO_APPID	= 0x8004a00c
    }	DCOMPERM_RESULTS;
